Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(70)

Unified Diff: src/compilation-cache.h

Issue 28027: Speed up access to global variables from eval scopes. Traverse the... (Closed) Base URL: http://v8.googlecode.com/svn/branches/bleeding_edge/
Patch Set: '' Created 11 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/codegen-ia32.cc ('k') | src/compilation-cache.cc » ('j') | src/objects.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compilation-cache.h
===================================================================
--- src/compilation-cache.h (revision 1344)
+++ src/compilation-cache.h (working copy)
@@ -55,10 +55,11 @@
int line_offset,
int column_offset);
// Finds the function boilerplate for a source string for
// eval. Returns an empty handle if the cache doesn't contain a
// script for the given source string.
static Handle<JSFunction> LookupEval(Handle<String> source,
+ Handle<Context> context,
Entry entry);
// Returns the regexp data associated with the given regexp if it
@@ -78,6 +79,14 @@
Entry entry,
Handle<JSFunction> boilerplate);
+ // Associate the (source, context->closure()->shared(), kind)
+ // tripple with the boilerplate. This may overwrite an existing
Kasper Lund 2009/02/24 11:21:08 tripple -> triple
+ // mapping.
+ static void PutEvalFunction(Handle<String> source,
+ Handle<Context> context,
+ Entry entry,
+ Handle<JSFunction> boilerplate);
+
// Clear the cache - also used to initialize the cache at startup.
static void Clear();
« no previous file with comments | « src/codegen-ia32.cc ('k') | src/compilation-cache.cc » ('j') | src/objects.cc » ('J')
@@ -55,10 +55,11 @@
int line_offset,
int column_offset);
- // Finds the function boilerplate for a source string for
- // eval. Returns an empty handle if the cache doesn't contain a
- // script for the given source string.
+ // Finds the function boilerplate for a source string for eval in a
+ // given context. Returns an empty handle if the cache doesn't
+ // contain a script for the given source string.
static Handle<JSFunction> LookupEval(Handle<String> source,

Powered by Google App Engine
This is Rietveld 408576698